@@ -21,14 +21,9 @@ from __future__ import annotations
 
 from typing import TYPE_CHECKING
 
-from github import Github as GithubClient
+from github import Auth, Github as GithubClient
 
-from airflow.exceptions import AirflowException
-
-try:
-    from airflow.sdk import BaseHook
-except ImportError:
-    from airflow.hooks.base import BaseHook  # type: ignore[attr-defined,no-redef]
+from airflow.providers.common.compat.sdk import BaseHook
 
 
 class GithubHook(BaseHook):
@@ -59,17 +54,35 @@ class GithubHook(BaseHook):
         conn = self.get_connection(self.github_conn_id)
         access_token = conn.password
         host = conn.host
+        extras = conn.extra_dejson or {}
 
-        # Currently the only method of authenticating to GitHub in Airflow is via a token. This is not the
-        # only means available, but raising an exception to enforce this method for now.
-        # TODO: When/If other auth methods are implemented this exception should be removed/modified.
-        if not access_token:
-            raise AirflowException("An access token is required to authenticate to GitHub.")
+        if access_token:
+            auth: Auth.Auth = Auth.Token(access_token)
+        elif extras:
+            if key_path := extras.get("key_path"):
+                if not key_path.endswith(".pem"):
+                    raise ValueError("Unrecognised key file: expected a .pem private key")
+                with open(key_path) as key_file:
+                    private_key = key_file.read()
+            else:
+                raise ValueError("No key_path provided for GitHub App authentication.")
+
+            app_id = extras.get("app_id")
+            installation_id = extras.get("installation_id")
+            if not isinstance(installation_id, int):
+                raise ValueError("The provided installation_id should be integer.")
+            if not isinstance(app_id, (str | int)):
+                raise ValueError("The provided app_id should be integer or string.")
+            token_permissions = extras.get("token_permissions", None)
+
+            auth = Auth.AppAuth(app_id, private_key).get_installation_auth(installation_id, token_permissions)
+        else:
+            raise ValueError("No access token or authentication method provided.")
 
         if not host:
-            self.client = GithubClient(login_or_token=access_token)
+            self.client = GithubClient(auth=auth)
         else:
-            self.client = GithubClient(login_or_token=access_token, base_url=host)
+            self.client = GithubClient(auth=auth, base_url=host)
 
         return self.client
 
